@@ -1,4 +1,4 @@
 # emacs: -*- mode: python-mode; py-indent-offset: 2; tab-width: 2; indent-tabs-mode: nil -*-
 # ex: set sts=2 ts=2 sw=2 et:
 
-__all__ = ['decode', 'meta', 'ml', 'network', 'reduce', 'stats']
+__all__ = ['classify', 'decode', 'meta', 'ml', 'network', 'plotutils', 'reduce', 'stats']
